<template>
    <q-dialog v-model="open" v-bind="dialogProps">
        <q-card class="bg-grey-1" :class="[size]">

            <q-scroll-area v-bind="props" :style="style">
                <slot ref="form" @mounted="formLoaded"></slot>
            </q-scroll-area>
            <q-separator />
            <q-card-actions align="right">
                <q-btn unelevated label="Submit" color="primary" @click="$emit('submit')" />
                <q-btn flat label="Close" color="red" v-close-popup />
            </q-card-actions>

        </q-card>
    </q-dialog>
</template>
<script>
export default {
    props: ['model-value', 'size'],
    watch: {
        open(val) {
            this.$emit('update:model-value', val)
        },
        modelValue(val) {
            this.open = val
        }
    },
    data() {
        return {
            open: false,
            style: {
                height: '70vh',
            },
            props: {
                thumbStyle: {
                    right: '4px',
                    borderRadius: '5px',
                    backgroundColor: '#027be3',
                    width: '5px',
                    opacity: 0.75
                },

                barStyle: {
                    right: '2px',
                    borderRadius: '9px',
                    backgroundColor: '#027be3',
                    width: '9px',
                    opacity: 0.2
                }
            }
        }
    },
    computed: {
        dialogProps() {
            let props = Object.assign({}, this.$attrs)
            if (Quasar.Screen.lt.sm) {
                console.log(props)
                props.maximized = true
                props.transitionShow = 'slide-up'
                props.transitionHide = 'slide-down'
            }
            return props
        }
    },
    methods: {
        formLoaded(el) {
            let height = el.clientHeight
            if (Quasar.Screen.lt.sm) {
                this.style.height = '85vh'
            } else {
                if (height / Quasar.Screen.height < 0.7) {
                    this.style.height = height + 'px'
                } else {
                    this.style.height = '80vh'
                }
            }

        }
    }
}
</script>